@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-auto-scroller.c,v 1.10 2005/12/08 13:36:55 chpe Exp $
+ *  $Id: ephy-auto-scroller.c,v 1.10.2.1 2006/04/10 20:29:29 chpe Exp $
  */
 
 /* this file is based on work of Daniel Erat for galeon 1 */
@@ -181,7 +181,10 @@ ephy_auto_scroller_grab_notify_cb (GtkWidget *widget,
 {
 	LOG ("Grab Notify [%p, window %p]", scroller, scroller->priv->window);
 
-	ephy_auto_scroller_stop (scroller, GDK_CURRENT_TIME /* FIXME? */);
+	if (was_grabbed)
+	{
+		ephy_auto_scroller_stop (scroller, GDK_CURRENT_TIME /* FIXME? */);
+	}
 }
 
 static int
