@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-certificates-extension.c,v 1.25 2005/04/19 11:30:17 chpe Exp $
+ *  $Id: ephy-certificates-extension.c,v 1.28.2.1 2006/04/09 20:24:23 chpe Exp $
  */
 
 #include "config.h"
@@ -50,6 +50,7 @@
 struct EphyCertificatesExtensionPrivate
 {
 	GtkWidget *cert_manager;
+	GtkWidget *device_manager;
 };
 
 typedef struct
@@ -59,6 +60,7 @@ typedef struct
 } WindowData;
 
 #define CERT_MANAGER_URL	"chrome://pippki/content/certManager.xul"
+#define DEVICE_MANAGER_URL	"chrome://pippki/content/device_manager.xul"
 #define WINDOW_DATA_KEY "EphyCertificatesExtensionWindowData"
 
 static void ephy_certificates_extension_class_init	 (EphyCertificatesExtensionClass *klass);
@@ -122,15 +124,28 @@ static void
 ephy_certificates_extension_finalize (GObject *object)
 {
 	EphyCertificatesExtension *extension = EPHY_CERTIFICATES_EXTENSION (object);
+	EphyCertificatesExtensionPrivate *priv = extension->priv;
 
 	LOG ("EphyCertificatesExtension finalising");
 
-	if (extension->priv->cert_manager)
+	if (priv->cert_manager)
 	{
-		g_object_remove_weak_pointer (G_OBJECT (extension->priv->cert_manager),
-					      (gpointer *) &extension->priv->cert_manager);
-		gtk_widget_destroy (extension->priv->cert_manager);
-		extension->priv->cert_manager = NULL;
+		GtkWidget **cert_manager = &priv->cert_manager;
+
+		g_object_remove_weak_pointer (G_OBJECT (priv->cert_manager),
+					      (gpointer *) cert_manager);
+		gtk_widget_destroy (priv->cert_manager);
+		priv->cert_manager = NULL;
+	}
+
+	if (priv->device_manager)
+	{
+		GtkWidget **device_manager = &priv->device_manager;
+
+		g_object_remove_weak_pointer (G_OBJECT (priv->device_manager),
+					      (gpointer *) device_manager);
+		gtk_widget_destroy (priv->device_manager);
+		priv->device_manager = NULL;
 	}
 
 	G_OBJECT_CLASS (parent_class)->finalize (object);
@@ -140,25 +155,62 @@ static void
 manage_certificates_cb (GtkAction *action,
 			EphyCertificatesExtension *extension)
 {
+	EphyCertificatesExtensionPrivate *priv = extension->priv;
 	EphyEmbedSingle *single;
-	GtkWidget *manager, *window;
+	GtkWidget *manager, *window, **widget;
 
-	if (extension->priv->cert_manager != NULL)
+	if (priv->cert_manager != NULL)
 	{
-		gtk_window_present (GTK_WINDOW (extension->priv->cert_manager));
+		gtk_window_present (GTK_WINDOW (priv->cert_manager));
 		return;
 	}  
 
 	single = EPHY_EMBED_SINGLE (ephy_embed_shell_get_embed_single (embed_shell));
 	manager = ephy_embed_single_open_window (single, NULL, CERT_MANAGER_URL,
-						 "", "all,chrome");
+						 "", "all,chrome,dialog");
 	g_return_if_fail (manager != NULL);
 
 	window = gtk_widget_get_toplevel (manager);
+	g_return_if_fail (GTK_WIDGET_TOPLEVEL (window));
 
-	extension->priv->cert_manager = window;
-	g_object_add_weak_pointer (G_OBJECT (extension->priv->cert_manager),
-				   (gpointer *) &extension->priv->cert_manager);
+	gtk_window_set_role (GTK_WINDOW (window), "epiphany-certificate-manager");
+	gtk_window_set_title (GTK_WINDOW (window), _("Certificates"));
+
+	priv->cert_manager = window;
+	widget = &priv->cert_manager;
+	g_object_add_weak_pointer (G_OBJECT (priv->cert_manager),
+				   (gpointer *) widget);
+}
+
+static void
+manage_devices_cb (GtkAction *action,
+		   EphyCertificatesExtension *extension)
+{
+	EphyCertificatesExtensionPrivate *priv = extension->priv;
+	EphyEmbedSingle *single;
+	GtkWidget *manager, *window, **widget;
+
+	if (priv->device_manager != NULL)
+	{
+		gtk_window_present (GTK_WINDOW (priv->device_manager));
+		return;
+	}  
+
+	single = EPHY_EMBED_SINGLE (ephy_embed_shell_get_embed_single (embed_shell));
+	manager = ephy_embed_single_open_window (single, NULL, DEVICE_MANAGER_URL,
+						 "", "all,chrome,dialog");
+	g_return_if_fail (manager != NULL);
+
+	window = gtk_widget_get_toplevel (manager);
+	g_return_if_fail (GTK_WIDGET_TOPLEVEL (window));
+
+	gtk_window_set_role (GTK_WINDOW (window), "epiphany-security-device-manager");
+	gtk_window_set_title (GTK_WINDOW (window), _("Security Devices"));
+
+	priv->device_manager = window;
+	widget = &priv->device_manager;
+	g_object_add_weak_pointer (G_OBJECT (priv->device_manager),
+				   (gpointer *) widget);
 }
 
 static void
@@ -275,7 +327,13 @@ static const GtkActionEntry action_entries_1 [] =
 	  N_("Manage _Certificates"),
 	  NULL, /* shortcut key */
 	  N_("Manage your certificates"),
-	  G_CALLBACK (manage_certificates_cb) }
+	  G_CALLBACK (manage_certificates_cb) },
+	{ "ToolsSecurityDevicesManager",
+	  NULL /* stock icon */,
+	  N_("Manage Security _Devices"),
+	  NULL, /* shortcut key */
+	  N_("Manage your security devices"),
+	  G_CALLBACK (manage_devices_cb) }
 };
 static const GtkActionEntry action_entries_2 [] =
 {
@@ -287,15 +345,6 @@ static const GtkActionEntry action_entries_2 [] =
 	  G_CALLBACK (view_certificate_cb) }
 };
 
-static void
-free_window_data (WindowData *data)
-{
-	if (data) {
-		g_object_unref (data->action_group);
-		g_free (data);
-	}
-}
-
 static void
 impl_attach_window (EphyExtension *ext,
 		    EphyWindow *window)
@@ -340,7 +389,8 @@ impl_attach_window (EphyExtension *ext,
 	gtk_action_group_add_actions (action_group, action_entries_2,
 				      G_N_ELEMENTS (action_entries_2), window);
 
-	gtk_ui_manager_insert_action_group (manager, action_group, 0);
+	gtk_ui_manager_insert_action_group (manager, action_group, -1);
+	g_object_unref (win_data->action_group);
 
 	win_data->ui_id = ui_id = gtk_ui_manager_new_merge_id (manager);
 
@@ -358,12 +408,16 @@ impl_attach_window (EphyExtension *ext,
 			       "ToolsCertificateManagerItem",
 			       "ToolsCertificateManager",
 			       GTK_UI_MANAGER_MENUITEM, FALSE);
+	gtk_ui_manager_add_ui (manager, ui_id, "/menubar/ToolsMenu",
+			       "ToolsSecurityDevicesManagerItem",
+			       "ToolsSecurityDevicesManager",
+			       GTK_UI_MANAGER_MENUITEM, FALSE);
 	gtk_ui_manager_add_ui (manager, ui_id, "/menubar/ToolsMenu",
 			       "ToolsSCSep2", NULL,
 			       GTK_UI_MANAGER_SEPARATOR, FALSE);
 
 	g_object_set_data_full (G_OBJECT (window), WINDOW_DATA_KEY, win_data,
-				(GDestroyNotify) free_window_data);
+				(GDestroyNotify) g_free);
 
 	/* Synchronize */
 	if (GTK_WIDGET_REALIZED (window))
