@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: validate.cpp,v 1.12 2004/12/08 15:33:52 chpe Exp $
+ *  $Id: validate.cpp,v 1.13 2005/11/01 11:28:21 chpe Exp $
  */
 
 #include "config.h"
@@ -129,7 +129,7 @@ HtmlErrorFinder::handle_line (const char *msg)
 			     matches, 0);
 	if (regex_ret != 0)
 	{
-		g_warning ("Could not parse OpenSP string.: %s\n", msg);
+		g_warning ("Could not parse OpenSP string: %s\n", msg);
 		sgml_validator_append (this->mValidator,
 				       ERROR_VIEWER_ERROR,
 				       msg);
@@ -164,7 +164,7 @@ HtmlErrorFinder::handle_line (const char *msg)
 	description = msg + matches[5].rm_so;
 
 	verbose_msg =
-		g_strdup_printf (_("HTML error in %s on line %s:\n%s"),
+		g_strdup_printf (_("HTML error in “%s” on line %s:\n%s"),
 				 display_filename, line_number, description);
 
 	sgml_validator_append (this->mValidator, error_type, verbose_msg);
