@@ -15,19 +15,19 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: extensions-manager-ui.c,v 1.20 2006/03/12 14:15:59 chpe Exp $
+ *  $Id: extensions-manager-ui.c,v 1.20.2.1 2006/04/09 20:24:24 chpe Exp $
  */
 
 #include "config.h"
 
 #include "extensions-manager-ui.h"
 
-#include "ephy-gui.h"
-#include "ephy-debug.h"
-
 #include <epiphany/ephy-extensions-manager.h>
 #include <epiphany/ephy-shell.h>
 
+#include "ephy-gui.h"
+#include "ephy-debug.h"
+
 #include <gtk/gtkaboutdialog.h>
 #include <gtk/gtkcellrenderertext.h>
 #include <gtk/gtkcellrenderertoggle.h>
@@ -126,7 +126,10 @@ extensions_manager_ui_response_cb (GtkWidget *widget,
 {
 	if (response == GTK_RESPONSE_HELP)
 	{
-		ephy_gui_help (GTK_WINDOW (widget), "epiphany", "extending-epiphany");
+		ephy_gui_help_with_doc_id (GTK_WINDOW (widget),
+					   "epiphany-extensions",
+					   "epiphany-extensions",
+					   "epi-ext-manager");
 		return;
 	}
 
