@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-gesture.h,v 1.3 2005/08/28 12:30:03 chpe Exp $
+ *  $Id: ephy-gesture.h,v 1.4 2005/10/24 16:12:56 philipl Exp $
  */
 
 #ifndef EPHY_GESTURE_H
@@ -73,6 +73,8 @@ EphyEmbedEvent *ephy_gesture_get_event		(EphyGesture *gesture);
 
 void		ephy_gesture_set_event		(EphyGesture *gesture,
 						 EphyEmbedEvent *event);
+void		ephy_gesture_activate		(EphyGesture *gesture,
+						 const char *path);
 
 G_END_DECLS
 
