@@ -15,13 +15,13 @@
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
-*  $Id: rss-ui.c,v 1.4 2005/05/19 11:19:19 chpe Exp $
+*  $Id: rss-ui.c,v 1.10 2005/12/22 22:32:46 rslinckx Exp $
 */
 
 #include "config.h"
 
 #include "rss-ui.h"
-#include "rss-dbus.h"
+#include <dbus/dbus-glib.h>
 
 #include "ephy-gui.h"
 #include "ephy-dnd.h"
@@ -64,6 +64,8 @@ struct _RssUIPrivate
 	FeedList *list;
 	/* Embed in which we have the feeds */
 	EphyEmbed *embed;
+	/* The proxy to the rss reader */
+	DBusGProxy *proxy;
 	/* A boolean flag indicating a dbus error */
 	gboolean dbus_error;
 };
@@ -124,11 +126,6 @@ static GtkTargetEntry drag_targets[] =
 	{ EPHY_DND_TEXT_TYPE,	  0, 1 }
 };
 
-/* glade callbacks */
-void rss_ui_response_cb	(GtkWidget *button,
-				 int response,
-				 RssUI *dialog);
-
 static GObjectClass *parent_class = NULL;
 static GType type = 0;
 
@@ -150,7 +147,18 @@ rss_ui_subscribe_selected (GtkTreeModel *model,
 	
 	if (selected && feed != NULL && feed->title != NULL && feed->type != NULL && feed->address != NULL)
 	{				
-		success = rss_dbus_subscribe_feed (feed->address);
+		GError *error = NULL;
+		if (!dbus_g_proxy_call (priv->proxy, RSS_DBUS_SUBSCRIBE, &error,
+			G_TYPE_STRING, feed->address,
+			G_TYPE_INVALID,
+			G_TYPE_BOOLEAN, &success,
+			G_TYPE_INVALID))
+		{
+			LOG ("Error while retreiving method answer: %s", error->message);
+			g_error_free (error);
+			success = FALSE;
+		}
+	
 		if (success == FALSE)
 		{
 			GtkWidget *image;
@@ -170,7 +178,7 @@ rss_ui_subscribe_selected (GtkTreeModel *model,
 	return FALSE;
 }
 
-void
+static void
 rss_ui_response_cb (GtkWidget *widget,
 		    int response,
 		    RssUI *dialog)
@@ -392,7 +400,7 @@ rss_ui_drag_data_get_cb (GtkWidget *widget,
 	gtk_selection_data_set (selection_data,
 			        selection_data->target,
 			        8,
-			        feed->address,
+			        (const guchar*) feed->address,
 			        strlen (feed->address));
 
 	rss_newsfeed_free (feed);
@@ -510,8 +518,24 @@ rss_ui_populate_store (RssUI *dialog)
 
 static void
 rss_ui_init (RssUI *dialog)
-{		
+{
+	DBusGConnection *connection;
+	GError *error = NULL;
+	
 	dialog->priv = RSS_UI_GET_PRIVATE (dialog);
+	
+	connection = dbus_g_bus_get (DBUS_BUS_SESSION, &error);
+	if (connection == NULL)
+	{
+		LOG ("No connection to dbus:%s", error->message);
+		g_error_free (error);
+		return;
+    }
+    	
+	dialog->priv->proxy = dbus_g_proxy_new_for_name (connection,
+                                     RSS_DBUS_SERVICE,
+                                     RSS_DBUS_OBJECT_PATH,
+                                     RSS_DBUS_INTERFACE);
 }
 
 static GObject *
@@ -547,6 +571,9 @@ rss_ui_constructor (GType type,
 				  properties[PROP_CLOSE].id, &priv->close,
 				  NULL);
 
+	g_signal_connect (priv->dialog, "response",
+			  G_CALLBACK (rss_ui_response_cb), dialog);
+
 	priv->store = gtk_list_store_new (N_COLUMNS,
 					  RSS_TYPE_NEWSFEED,
 					  G_TYPE_STRING,
@@ -567,6 +594,7 @@ rss_ui_constructor (GType type,
 						     NULL);
 
 	renderer = gtk_cell_renderer_text_new ();
+	g_object_set (renderer, "ellipsize", PANGO_ELLIPSIZE_END, NULL);
 	gtk_tree_view_insert_column_with_attributes (priv->treeview,
 						     COL_DISPLAY, _("Description"),
 						     renderer,
@@ -610,6 +638,7 @@ rss_ui_finalize (GObject *object)
 	RssUI *dialog = RSS_UI (object);
 	RssUIPrivate *priv = dialog->priv;
 
+	g_object_unref (priv->proxy);
 	rss_feedlist_free (priv->list);
 	
 	parent_class->finalize (object);
