@@ -16,12 +16,10 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: sample-mozilla.c,v 1.2.2.2 2004/09/28 18:36:18 chpe Exp $
+ *  $Id: sample-mozilla.c,v 1.8 2005/01/28 22:30:21 chpe Exp $
  */
 
-#ifdef HAVE_CONFIG_H
 #include "config.h"
-#endif
 
 #include "ephy-sample2-extension.h"
 #include "ephy-debug.h"
@@ -34,11 +32,11 @@ G_MODULE_EXPORT GType register_module (GTypeModule *module);
 G_MODULE_EXPORT GType
 register_module (GTypeModule *module)
 {
-	LOG ("Registering EphySampleExtension")
+	LOG ("Registering EphySample2Extension");
 
 #ifdef ENABLE_NLS
        /* Initialise the i18n stuff */
-        bindtextdomain (GETTEXT_PACKAGE, EPHY_PLUGINS_LOCALEDIR);
+        bindtextdomain (GETTEXT_PACKAGE, EPHY_EXTENSIONS_LOCALEDIR);
         bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");	
 #endif /* ENABLE_NLS */
 
